@@ -1,8 +1,6 @@
-# Set of functions to create a grid cells from a custom polygon and convert it to API proof strings
-
 #' Create the polygon for the study area by drawing into a world map
 #'
-#' @param lat initial geographical coordinate for latititude in decimal degrees (EPSG:4326)
+#' @param lat initial geographical coordinate for latitude in decimal degrees (EPSG:4326)
 #' for the map to start at. Default = \dQuote{0}.
 #' @param lng initial geographical coordinate for longitude in decimal degrees (EPSG:4326)
 #' for the map to start at. Default = \dQuote{0}.
@@ -10,15 +8,16 @@
 #' @param editor type of editor for the drawing tools. Options are \dQuote{leafpm} (default)
 #' and \dQuote{leaflet.extras}. Requires additional packages \code{leafpm} and
 #' \code{leaflet.extras}, respectively.
-#' @return an object of class \sQuote{SpatialPolygon-class} with a polygon
-#' (only the first one drawn) with geodesic coordinates in WGS84 (ESPG:4326).
+#' @return an object of class \sQuote{sf} with a polygon (only the first one drawn)
+#' with geodesic coordinates in WGS84 (ESPG:4326).
 #' @export
 #' @examples
 #' if(interactive()){
 #'  polygon <- drawPolygon()
 #' }
 #' @importFrom magrittr %>%
-#' @importFrom sp spTransform CRS
+#' @importFrom sf st_transform st_crs st_geometry_type
+#' @importFrom mapedit editMap
 drawPolygon <- function(lat = 0,
                         lng = 0,
                         zoom = 1,
@@ -29,21 +28,24 @@ drawPolygon <- function(lat = 0,
       leaflet::setView(lng = lng, lat = lat, zoom = zoom) %>%
       leaflet::setMaxBounds(lng1 = -220, lat1 = 86, lng2 = 220, lat2 = -86)  #%>%
 
-    areaDrawn <- mapedit::editMap(map,
-                                  editor = "leafpm",
-                                  viewer = shiny::paneViewer(),
-                                  title = "Draw a polygon where to place the grid")
+    areaDrawn <- editMap(map,
+                         editor = "leafpm",
+                         viewer = shiny::paneViewer(),
+                         title = "Draw a polygon where to place the grid")
     area <- areaDrawn$finished$geometry
 
     # Observe the draw input
-    areaTypes <- sf::st_geometry_type(area)
+    areaTypes <- st_geometry_type(area)
     # check if there is a polygon
     if ("POLYGON" %in% areaTypes) {
         wPoly <- which(areaTypes == "POLYGON")
         if (length(wPoly) > 1)
             warning("Only the first polygon will go through")
-        polygon <- as(area[wPoly[1]], "Spatial")
-        polygon <- spTransform(polygon, CRSobj = CRS("+init=epsg:4326"))
+        polygon <- st_as_sf(area[wPoly[1]])
+
+        # polygon <- spTransform(polygon, CRSobj = CRS(crswkt))
+        polygon <- st_transform(polygon,
+                                crs = st_crs(4326))
     } else {
         stop("There are no polygones in your drawing")
     }
@@ -56,46 +58,56 @@ drawPolygon <- function(lat = 0,
 #' This function is based on the function shotGroups::getMinCircle() that uses
 #' the Skyum algorithm based on the convex hull. http://www.cs.au.dk/~gerth/slides/sven14.pdf
 #'
-#' @param spdf an object of class \sQuote{SpatialPointsDataFrame} with defined CRS.
-#' @param projCRS a proj4-type string defining a projected CRS. It is very important
+#' @param spdf an object of class \sQuote{sf} or \sQuote{SpatialPointsDataFrame}
+#' with defined CRS.
+#' @param crs a number defining a projected CRS. It is very important
 #' that the selected CRS is accurate in the study area. This is not the CRS for
 #' the argument 'spdf' which should be defined internally. This is the CRS used to
 #' make a flat circle. Some UTM variant is recommended. See \code{\link{getUTMproj}}
-#' @return a polygon object of class \sQuote{SpatialPolygon} with geodesic
+#' @return a polygon object of class \sQuote{sf} with geodesic
 #' coordinates in WGS84 (ESPG:4326).
 #' @seealso \code{\link{getUTMproj}}
 #' @importFrom shotGroups getMinCircle
 #' @export
-makeCircle<-function(spdf, projCRS=NULL){
+makeCircle<-function(spdf, crs=NULL){
     # error not a SpatialPolygon
-    if(!(class(spdf) %in% c("SpatialPoints", "SpatialPointsDataFrame")))
-      stop("The input object is neither of class 'SpatialPoints' nor 'SpatialPointsDataFrame'")
+    if(any(class(spdf) %in% c("SpatialPoints", "SpatialPointsDataFrame", "sf", "sfc")))
+      stop("The input object is neither of class 'sf', SpatialPoints' nor 'SpatialPointsDataFrame'")
+
+    if(any(class(spdf) %in% c("SpatialPoints", "SpatialPointsDataFrame") )){
+      spdf <- st_as_sf(spdf)
+    }
 
     ## error no CRS in spdf
-    if (is.na(slot(spdf, "proj4string"))) stop("The polygon has no coordinate projection system (CRS) associated")
+    if (is.na(st_crs(spdf)) ) stop("The polygon has no coordinate projection system (CRS) associated")
 
-    ## error projCRS not defined
-    if (is.null(projCRS)) stop("projCRS needs to be defined")
+    ## error crs not defined
+    if (is.null(crs)) stop("crs needs to be defined")
+    crs <- as.numeric(crs)
 
-    spdf <- suppressWarnings(spTransform(spdf, CRS(projCRS)) )
+    spdf <- st_transform(spdf,
+                         crs = st_crs(crs))
 
-    if (!is.na(sp::is.projected(spdf)) && !sp::is.projected(spdf))
+
+    if (!is.na(	st_is_longlat(spdf)) && st_is_longlat(spdf) )
       warning("Spatial object is not projected; this function expects planar coordinates")
 
-    coord <- coordinates(spdf)
+    coord <- do.call(rbind, st_geometry(spdf)) #coordinates(spdf)
     coordPaste <- apply(coord, 1, paste0, collapse = ",")
     coordUnique <- matrix(coord[!duplicated(coordPaste)], ncol = 2)
 
     if (nrow(coordUnique) > 1) {
       # the minumum circle that covers all points
       mincirc <- getMinCircle(coordUnique)
-      mincircSP<-data.frame(mincirc$ctr[1], mincirc$ctr[2])
-      colnames(mincircSP)<-c("X", "Y")
-      sp::coordinates(mincircSP) <- ~X+Y
-      sp::proj4string(mincircSP) <- projCRS
+      mincircSP<-st_as_sf(data.frame("X"=mincirc$ctr[1], "Y"=mincirc$ctr[2]),
+                          coords=c("X", "Y"))
+      st_crs(mincircSP) <- st_crs(crs)
 
-      circle <- rgeos::gBuffer(spgeom = mincircSP, width = mincirc$rad, quadsegs = 10)
-      circle <- spTransform(circle, CRSobj = suppressWarnings(CRS("+init=epsg:4326")))
+      circle <- st_buffer(mincircSP,
+                          dist = mincirc$rad,
+                          quadsegs = 10)
+      circle <- st_transform(circle,
+                             crs = st_crs(4326))
 
     } else {
         stop("More than one unique set of coordinates are needed to make a minimum circle polygon.")
@@ -107,9 +119,9 @@ makeCircle<-function(spdf, projCRS=NULL){
 }
 
 
-#' Create the polygon for the study area from a dataset of class \sQuote{OrganizedBirds}
+#' Create the polygon for the study area from a data set of class \sQuote{OrganizedBirds}
 #'
-#' @param x an object of class \sQuote{OrganizedBirds} or \sQuote{SpatialPointsDataFrame}
+#' @param x an object of class \sQuote{OrganizedBirds}, \sQuote{sf} or \sQuote{SpatialPointsDataFrame}
 #' @param shape which type of polygon should be made from the data:
 #' \itemize{
 #'   \item a bounding box (\dQuote{bBox} or \dQuote{bounding box}; i.e. the smallest bounding rectangle
@@ -119,213 +131,184 @@ makeCircle<-function(spdf, projCRS=NULL){
 #'   \item the minimum circle (\dQuote{minCircle} or \dQuote{min circle}; i.e. the smallest
 #'   circle that covers all the points).
 #' }
-#' @return an object of class \sQuote{SpatialPolygon} with a polygon with geodesic
-#' coordinates in WGS84 (ESPG:4326).
+#' @return an object of class \sQuote{sf} with a polygon with geodesic coordinates
+#'  in WGS84 (ESPG:4326).
 #' @examples
-#' orgDf <- organizeBirds(bombusObs)
-#' polygon <- OB2Polygon(orgDf, shape = "cHull")
-#' @importFrom sp bbox coordinates proj4string spTransform CRS Polygon Polygons SpatialPolygons
+#' \donttest{
+#'   ob <- organizeBirds(bombusObs)
+#'   polygon <- OB2Polygon(ob, shape = "cHull")
+#' }
 #' @export
 OB2Polygon <- function(x, shape="bBox") {
-    if (class(x) == "OrganizedBirds") {
-        spdf <- x$spdf
-    } else {
-        if(class(x) == "SpatialPointsDataFrame"){
-            spdf <- x
-            spdf <- spTransform(spdf, CRSobj = suppressWarnings(CRS("+init=epsg:4326")))
-        } else {
-            stop("input data is neither an object of class 'OrganizedBirds' or 'SpatialPointsDataFrame'")
-        }
-    }
 
-    ## error no CRS
-    # if (is.na(proj4string(spdf))) {
-    #     stop("The polygon has no coordinate projection system (CRS) associated")
-    # }
-    if (is.na(slot(spdf, "proj4string"))) {
-      stop("The polygon has no coordinate projection system (CRS) associated")
-    }
+  if (is.null(shape)) shape <- "bBox"
 
-    coord <- coordinates(spdf)
-    coordPaste <- apply(coord, 1, paste0, collapse = ",")
-    coordUnique <- matrix(coord[!duplicated(coordPaste)], ncol = 2)
+  if (!any(class(x) %in% c("OrganizedBirds", "sf", "SpatialPointsDataFrame")))
+           stop("input data is neither an object of class 'OrganizedBirds', 'sf' or 'SpatialPointsDataFrame'")
 
-    if (is.null(shape)) shape<-"bBox"
+  if (class(x) == "OrganizedBirds") {
+      spdf <- x$spdf
+      if(any(class(spdf) == "SpatialPointsDataFrame")){
+        spdf <- st_as_sf(spdf)
+      }
+  } else if(any(class(x) == "SpatialPointsDataFrame")){
+          spdf <- x
+          spdf <- st_as_sf(spdf)
+  } else if(any(class(x) == "sf")){
+    spdf <- x
+  }
 
-    if (shape %in% c("bBox", "bounding box")){
-        bboxMat<-bbox(spdf)
-        polygonCoord <- matrix(c(bboxMat[1,1], bboxMat[2,1],
-                           bboxMat[1,1], bboxMat[2,2],
-                           bboxMat[1,2], bboxMat[2,2],
-                           bboxMat[1,2], bboxMat[2,1],
-                           bboxMat[1,1], bboxMat[2,1]), ncol = 2, nrow = 5, byrow = TRUE)
-        polygon <- SpatialPolygons(
-            list(
-                Polygons(
-                    list(
-                        Polygon( polygonCoord )
-                        ),
-                    ID="1")
-                ),
-            proj4string=CRS("+init=epsg:4326")
-            )
-    }
+  if (is.na(st_crs(spdf)))
+    stop("The polygon has no coordinate projection system (CRS) associated")
 
-    if (shape %in% c("cHull", "convex hull")) {
-        if (nrow(coordUnique) > 2) {
-            hpts <- grDevices::chull(coord)
-            hpts <- c(hpts, hpts[1])
-            polygon<-SpatialPolygons(
-                list(
-                    Polygons(
-                        list(
-                            Polygon( coord[hpts, ] )
-                            ),
-                        ID="1")
-                    ),
-                proj4string=CRS("+init=epsg:4326")
-                )
-        } else {
-            stop("More than two unique set of coordinates is needed to make a
-                 convex hull polygon.")
-        }
-    }
+  crs <- st_crs(getUTMproj(spdf))
 
-    if (shape %in% c("minCircle", "min circle")) {
-      proj4UTM <- getUTMproj(spdf)
-      polygon <- makeCircle(spdf, projCRS = proj4UTM)
-    } # end shape conditions
+  spdf <- st_transform(spdf,
+                       crs = crs)
 
-    return(polygon)
+  coord <- do.call(rbind, st_geometry(spdf))
+  coordPaste <- apply(coord, 1, paste0, collapse = ",")
+  coordUnique <- matrix(coord[!duplicated(coordPaste)], ncol = 2)
+
+  if (shape %in% c("bBox", "bounding box")){
+      polygon <- st_as_sfc(st_bbox(spdf))
+  }
+  if (shape %in% c("cHull", "convex hull")) {
+      if (nrow(coordUnique) > 2) {
+          polygon <- spdf %>%
+            st_union() %>%
+            # dplyr::group_by() %>%
+            # dplyr::summarise() %>%
+            st_convex_hull()
+      } else {
+          stop("More than two unique set of coordinates is needed to make a
+               convex hull polygon.")
+      }
+  }
+
+  if (shape %in% c("minCircle", "min circle")) {
+    polygon <- makeCircle(spdf, crs = crs)
+  } # end shape conditions
+
+  polygon <- st_transform(polygon, crs = st_crs(4326))
+  return(polygon)
 }
 
 #' Rename the cells in a grid
 #'
-#' Takes a SpatialPolygon* and renames it to "ID1":"IDn".
-#' @param grid an object of class \sQuote{SpatialPolygon-class} or
-#' \sQuote{SpatialPolygonDataFrame-class}.
+#' Takes a sf* and renames it to "ID1":"IDn".
+#' @param grid an object of class \sQuote{sf}.
+#' @param idcol column name with names or ids
 #' @return the same input object with known names
 #' @keywords internal
-renameGrid<-function(grid){
-    for(i in 1:length(grid)){
-      # grid@polygons[[i]]@ID <- paste0("ID", i)
-      slot(slot(grid, "polygons")[[i]], "ID") <- paste0("ID", i)
-    }
+renameGrid <- function(grid, idcol="id"){
+  nrows <- nrow(grid)
+  grid[, idcol] <- paste0("ID", seq(nrows))
   return(grid)
 }
 
 
 #' Make a grid
 #'
-#' Makes a grid adapted to the purpose of this package and simplifing options
-#' from the  \code{sp} package. The central concept of the BIRDS package is the
+#' Makes a grid adapted to the purpose of this package and simplifying options
+#' from the  \code{sf} package. The central concept of the BIRDS package is the
 #' definition of the field visit, and most likely, your grid size will define the
 #' maximum area a person can explore during a day. Use the function
 #' \code{exploreVisits()} to assess if your definition of visit aligns with your
 #'  grid size.
-#' @param polygon an object of class \sQuote{SpatialPolygon} or
+#' @param poly an object of class \sQuote{sf},  \sQuote{SpatialPolygon} or
 #' \sQuote{SpatialPolygonDataFrame}
 #' @param gridSize width of the cells in Km. It defines the central assumption
 #' of this package that is the maximum area a person can explore during a day.
-#' Be aware, that the spatial extent of a visit is dependent on the taxonomic group, and many other variables.
-#' Maximum recomended for this package 10 km if there is no reliable definition
-#' for the spatial extent for visits.
+#' Be aware, that the spatial extent of a visit is dependent on the taxonomic
+#' group, and many other variables. Maximum recommended for this package 10 km
+#' if there is no reliable definition for the spatial extent for visits.
 #' @param buffer shall the grid cells include the polygon border? Then \code{TRUE}
 #' (default = \code{FALSE}).
 #' @param hexGrid shall the grid cells be hexagonal? Then \code{TRUE} (default).
 #' Else squared grid cells.
-#' @param offset the offset (position) of the grid (from \code{spsample} methods).
-#' If it is left empty (\code{NULL}, default), then takes default values.
-#' For squared grid cells the default is set to \code{c(0.5,0.5)} ("centric systematic").
-#' For hexagonal grid cells the default is set to \code{c(0,0)}.
-#' @param simplify simplifies the polygon geometry using the Douglas-Peuker algorithm  (from rgeos package).
-#' Complicated polygons (those with much detail) make this function run slower.
-#' @param tol numerical tolerance value for the simplification algorith. Set to 0.01 as default.
-#' @return an object of class \sQuote{SpatialPolygon} with a set of polygons
-#' conforming to a grid of equal-area cells, with geodesic coordinates in WGS84 (ESPG:4326).
-#' @note Depending on the total number of grid cells the computations may take time.
-#' If there are more than 100 cells on any dimension a warning message will be displayed.
-#' Grid cells must be smaller than the sampling area. If the grid cell size is wider than the polygon on any dimension
-#' an error message will be displayed.
+#' @param offset numeric of length 2 with lower left corner coordinates (x, y)
+#' of the grid. If it is left empty (\code{NULL}, default), then takes default
+#' values \code{st_bbox(x)[c("xmin", "ymin")]}.
+#' @param simplify simplifies the polygon geometry. Complicated polygons (those
+#' with much detail) make this function run slower.
+#' @param tol numerical tolerance value for the simplification algorithm. Set to
+#' 0.01 as default.
+#' @return an object of class \sQuote{sf} with a set of polygons conforming to a
+#' grid of equal-area cells, with geodesic coordinates in WGS84 (ESPG:4326).
+#' @note Depending on the total number of grid cells the computations may take
+#' time. If there are more than 500 cells on any dimension a warning message will
+#' be displayed. Grid cells must be smaller than the sampling area. If the grid
+#' cell size is wider than the polygon on any dimension an error message will be
+#' displayed.
 #' @examples
+#' \donttest{
 #' grid <- makeGrid(gotaland, gridSize = 10)
+#' }
 #' @seealso \code{\link{drawPolygon}}, \code{\link{renameGrid}}, \code{\link{OB2Polygon}}, \code{\link{exploreVisits}}
-#' @importFrom sp coordinates proj4string spTransform CRS over
+#' @importFrom sf st_crs as_Spatial st_transform st_as_sf
 #' @export
-makeGrid <- function(polygon,
+makeGrid <- function(poly,
                      gridSize,
-                     buffer = FALSE,
                      hexGrid = TRUE,
-                     offset=NULL,
-                     simplify=FALSE,
-                     tol=0.01) {
+                     offset = NULL,
+                     buffer = FALSE,
+                     simplify = FALSE,
+                     tol = 0.01) {
 
     gridSizeM <- gridSize * 1000 # in meters
-    gridSizeDg <- gridSize/111  # because on average 1 degree is 111 km
 
-    # error not a SpatialPolygon
-    if (!(class(polygon) %in% c("SpatialPolygons", "SpatialPolygonsDataFrame"))) {
-        stop("Entered polygon is not a SpatialPolygon nor SpatialPolygonsDataFrame")
+    if (!any(class(poly) %in% c("sfc","sf","SpatialPolygons", "SpatialPolygonsDataFrame"))) {
+        stop("Entered polygon is not an sf, SpatialPolygon nor SpatialPolygonsDataFrame")
     }
 
+    if (any(class(poly) %in% c("SpatialPolygons", "SpatialPolygonsDataFrame"))) {
+      poly <- st_as_sf(poly)
+    }
     ## error no CRS
-    if (is.na(slot(polygon, "proj4string"))) {
+    if (is.na(st_crs(poly))) {
         stop("The polygon has no coordinate projection system (CRS) associated")
     }
 
-    ## simplify if takes too long to make the grid
-    if (simplify) {
-      ##TODO apply tryCatch()
-      polygon <- rgeos::gSimplify(polygon, tol = tol)
+    if(is.null(offset)){
+      offset <- st_bbox(poly)[c("xmin", "ymin")]
+    } else {
+      if(length(offset) != 2|| !all(is.integer(offset)) ||!is.numeric(offset))
+        stop("Offset should be either NULL or numeric of length 2; lower left corner coordinates (x, y) of the grid")
     }
 
-    # Transform to WGS84 pseudo-Mercator
-    polygonProj <- suppressWarnings(spTransform(polygon,
-                                                CRSobj = CRS("+init=epsg:3857"))
-                                    )
-    if (buffer) {
-        # Needs to be projected
-        polygonProjBuffer <- rgeos::gBuffer(polygonProj, width = gridSizeM)
-    } else {polygonProjBuffer <- polygonProj}
-
-    polygonGeod <- suppressWarnings(spTransform(polygonProjBuffer,
-                                                CRSobj = CRS("+init=epsg:4326"))
-                                    )
+    poly <- st_transform(poly,
+                         crs = st_crs(getUTMproj(poly)))
 
     # observe the grid cell and study area polygon get the difference in
     # longitude/latitude to make the condition
-    # dif <- diff(t(polygonProj@bbox))
-    dif <- diff(t(slot(polygonProj, "bbox")))
+    dif <- as.numeric(diff(matrix(st_bbox(poly), ncol=2)))
 
     if (any(gridSizeM >= dif)) {
-        stop("Grid cells must be smaller than the sampling area")
+      stop("Grid cells must be smaller than the sampling area")
     }
-    if (any(gridSizeM <= dif/100)) {
-        warning("Grid cells are too small, this may result in very long computation times")
+    if (any(gridSizeM <= dif/500)) {
+      message("Grid cells are too many (>=500), this may result in very long computation times")
     }
 
-    # Create the actual grid
-    if (hexGrid == TRUE) {
-        if (is.null(offset)){
-            offset <- c(0, 0)
-        }
-        points <- sp::spsample(polygonGeod, type = "hexagonal",
-                               offset = offset,
-                               cellsize = gridSizeDg)
-        grid <- sp::HexPoints2SpatialPolygons(points)
-    } else {
-        if (is.null(offset)){
-            offset <- c(0.5, 0.5)
-        }
-        points <- sp::spsample(polygonGeod, type = "regular",
-                               offset = offset,
-                               cellsize = gridSizeDg)
-        grid <- sp::as.SpatialPolygons.GridTopology(sp::points2grid(points),
-                                              proj4string = CRS("+init=epsg:4326"))
-
-        wcells <- over(points, grid)
-        grid <- grid[wcells, ]
+    if(simplify){
+      poly <- st_simplify(poly, dTolerance = tol)
     }
+
+    if (buffer) {
+      poly <- st_buffer(poly, dist = gridSizeM)
+    }
+
+    # poly <- st_transform(poly,
+    #                      crs = st_crs(4326))
+
+    grid <- st_make_grid(poly,
+                         cellsize = gridSizeM,
+                         square = !hexGrid,
+                         offset = offset,
+                         what = "polygons")
+
+    grid <- st_transform(grid, crs = st_crs(4326))
     return(grid)
 }
 
@@ -365,12 +348,11 @@ makeGrid <- function(polygon,
 # #' Grid cells must be smaller than the sampling area. If the grid cell size is wider than the polygon on any dimension
 # #' an error message will be displayed.
 # #' @seealso \code{\link{drawPolygon}}, \code{\link{renameGrid}}, \code{\link{OB2Polygon}}, \code{\link{exploreVisits}}
-# #' @importFrom sp bbox coordinates proj4string spTransform CRS Polygon Polygons SpatialPolygons
 # #' @importFrom dplyr group_map
 # #' @importFrom rlang .data
 # #' @importFrom utils installed.packages
 # #' @export
-# makeDggrid <- function(polygon,
+# makeDggrid <- function(poly,
 #                      gridSize,
 #                      buffer = FALSE,
 #                      topology = "hexagon",
@@ -398,25 +380,25 @@ makeGrid <- function(polygon,
 #                       resround='nearest', topology = topology, aperture = aperture)
 #
 #   # error not a SpatialPolygon
-#   if (!(class(polygon) %in% c("SpatialPolygons", "SpatialPolygonsDataFrame"))) {
+#   if (!(class(poly) %in% c("SpatialPolygons", "SpatialPolygonsDataFrame"))) {
 #     stop("Entered polygon is not a SpatialPolygon nor SpatialPolygonsDataFrame")
 #   }
 #
 #   ## error no CRS
-#   if (is.na(slot(polygon,"proj4string"))) {
+#   if (is.na(slot(poly,"proj4string"))) {
 #     stop("The polygon has no coordinate projection system (CRS) associated")
 #   }
 #
 #   ## simplify if takes too long to make the grid
 #   if (simplify) {
 #     ##TODO use tryCatch()
-#     polygon <- rgeos::gSimplify(polygon, tol = tol)
+#     poly <- rgeos::gSimplify(poly, tol = tol)
 #   }
 #
 #   # Transform to WGS84 pseudo-Mercator
 #   if (buffer) {
 #     # Needs to be projected
-#     polygonProj <- suppressWarnings(spTransform(polygon,
+#     polygonProj <- suppressWarnings(spTransform(poly,
 #                                                 CRSobj = CRS("+init=epsg:3857")) )
 #     polygonBuffer <- rgeos::gBuffer(polygonProj, width = gridSize*1000)
 #   } else {polygonBuffer <- polygon}
@@ -457,19 +439,28 @@ makeGrid <- function(polygon,
 #' @export
 gridAsString <- function(grid) {
     # error not a SpatialPolygon
-    if (!(class(grid) %in% c("SpatialPolygons", "SpatialPolygonsDataFrame"))) {
-        stop("Entered grid is not a SpatialPolygon nor SpatialPolygonsDataFrame")
+    if (!any(class(grid) %in% c("sf","SpatialPolygons", "SpatialPolygonsDataFrame"))) {
+        stop("Entered grid is not a sf, SpatialPolygon nor SpatialPolygonsDataFrame")
     }
+    if (any(class(grid) %in% c("SpatialPolygons", "SpatialPolygonsDataFrame"))) {
+      grid <- st_as_sf(grid)
+    }
+    grid <- st_transform(grid, crs = st_crs(4326))
 
     ncells <- length(grid)
     polyStrg <- list()
     for (i in 1:ncells){
 
-      polyStrg[[i]] <- paste0(apply(slot(slot(slot(grid, "polygons")[i][[1]],
-                                              "Polygons")[[1]],
-                                         "coords"),  #grid@polygons[i][[1]]@Polygons[[1]]@coords,
-                                    1, paste0, collapse = "%20"),
-                              collapse = ",")
+      polyStrg[[i]] <- gsub(" ","%20",
+                            gsub(", ", ",",
+                                 gsub( "))", "",
+                                       gsub("POLYGON ((", "",
+                                            st_as_text(grid[i]),
+                                            fixed=TRUE),
+                                       fixed=TRUE),
+                                 fixed=TRUE),
+                            fixed=TRUE)
+
     }
 
 
