@@ -14,7 +14,6 @@
 #' @return A vector with the column names that match the pattern
 #' @export
 #' @keywords internal
-
 findCols <- function(pattern, df, exact=FALSE, value = TRUE){
   if(missing(pattern)) stop("The argument 'pattern' must be supplied.")
   if(missing(df)) stop("The argument 'df' must be supplied.")
@@ -32,9 +31,9 @@ findCols <- function(pattern, df, exact=FALSE, value = TRUE){
 
 #' Organize the date-column(s)
 #'
-#' Organize the date-column(s) in a dataframe to three columns
+#' Organize the date-column(s) in a data.frame to three columns
 #'
-#' @param x A dataframe with at least the columns specified in 'columns'
+#' @param x A data.frame with at least the columns specified in 'columns'
 #' @param columns A character vector with the column names for the dates specified.
 #'   It can either be one column formatted as "yyyy-mm-dd" or a vector of
 #'   length=3. If the column names are "year", "month" and "day" it will take
@@ -52,6 +51,7 @@ findCols <- function(pattern, df, exact=FALSE, value = TRUE){
 #' @keywords internal
 organizeDate <- function(x, columns){
   if (!length(columns) %in% c(1,3)) stop("Could not create date, please specify either one or three column names")
+
   stdTimeCols <- c("year", "month", "day")
 
   cols.df <- findCols(columns, x, exact = TRUE)
@@ -127,7 +127,7 @@ print(res)
 #'
 #' Removes infraspecific epithets, authors and years from scientific names
 #'
-#' @param df A dataframe with at least the column specified in sppCol
+#' @param df A data.frame with at least the column specified in sppCol
 #' @param sppCol A character vector with the column names for the species names.
 #' @return A vector with data.frame with a canonical name given by taxize::gbif_parse(),
 #' that is a scientific name with up to 3 elements and no authorship
@@ -135,7 +135,8 @@ print(res)
 #' @export
 simplifySpp <- function(df, sppCol){
 
-  simpleSpp <- gbif_parse(df[, sppCol])$canonicalname
+  gbifdf <-  gbif_parse(df[, sppCol])
+  simpleSpp <- gbifdf$canonicalname
 
   # splitLits <- strsplit(as.character(df[, sppCol]), "\ ")
   #
@@ -160,44 +161,64 @@ simplifySpp <- function(df, sppCol){
 }
 
 
-### HANDLE THE VISITS ###
+#### HANDLE THE VISITS ####
 #' Create unique IDs based on a grid
 #'
-#' Takes a spatial points dataframe and a grid and gets the overlay IDs.
+#' Takes a spatial points data.frame and a grid and gets the overlay IDs.
 #'
-#' @param x a SpatialPointsDataFrame .
-#' @param grid A a SpatialPolygon object (a grid is expected) defining the
+#' @param x a SpatialPointsDataFrame ('sp') or sf ('sf') (with the observations).
+#' @param grid a SpatialPolygon object ('sp') or sf ('sf') (a grid is expected) defining the
 #' maximum extent of visits effort.
+#' @param idcol column name for the grid names or ids
 #'
 #' @return A vector of the same length as the number of rows (observations) as x
 #'   with a unique number corresponding to the grid's ID.
 #'
 #' @export
-getGridIDs <- function(x, grid){
-  if(class(x) == "SpatialPointsDataFrame"){
-    if(class(grid) %in% c("SpatialPolygonsDataFrame", "SpatialPolygons")){
-      #### Rename grid
-      if (any(duplicated(names(grid)))){
-        grid <- renameGrid(grid)
-        warning("There are duplicated cell names in your grid. We rename them internally to 'ID1'...'IDn'.
-      All results will use this nomenclature, but the order of the cells will remain unaltered.")
-      }
+getGridIDs <- function(x, grid, idcol="id"){
+  if(!any(class(x) %in% c("SpatialPointsDataFrame", "sf"))) {
+    stop("The argument 'x' can only be of class sf or SpatialPointsDataFrame")
+  }
 
-      if(! identicalCRS(x, grid)){
-        grid <- spTransform(grid, slot(x,"proj4string"))
+  if(any(class(x) == "SpatialPointsDataFrame")) x <- st_as_sf(x)
+
+  if(!any(class(grid) %in% c("SpatialPolygonsDataFrame", "SpatialPolygons", "sf"))){
+    stop("The argument 'grid' can only be of class sf, SpatialPolygonsDataFrame or SpatialPolygons")
+  }
+
+  if(any(class(grid) %in% c("SpatialPolygonsDataFrame", "SpatialPolygons"))) grid <- st_as_sf(grid)
+
+  if(is.null(idcol)) idcol="id"
+  #### Rename grid
+  if(is.null(colnames(grid))){
+    grid <- st_sf(data.frame(paste0("ID", seq(length(grid))), st_geometry(grid)))
+    colnames(grid)[1]<-idcol
+  } else {
+    if(!idcol %in% colnames(grid)) stop(paste0("The column '",idcol,"' was not found in the grid"))
+    if (any(duplicated(grid[,idcol]))){
+      grid <- renameGrid(grid, idcol)
+      warning("There are duplicated cell names in your grid. We rename them internally to 'ID1'...'IDn'.
+All results will use this nomenclature, but the order of the cells will remain unaltered.")
       }
+  }
+
+  x <- st_transform(x,
+                    crs = st_crs(3857))
+  grid <- st_transform(grid,
+                       crs = st_crs(3857))
+  inter <-st_intersects(x, grid)
+  res <- sapply(inter,
+                function(z) if (length(z)==0) NA_integer_ else z[1])
+  return(res)
 
-      return( over(x, grid, returnList=FALSE) )
-    }else stop("The argument 'grid' can only be of class SpatialPolygonsDataFrame or SpatialPolygons")
-  } else stop("The argument 'x' can only be of class SpatialPointsDataFrame")
 }
 
 
 
 #' Create unique visits IDs
 #'
-#' Takes a dataframe and a vector of column names and classifies each row of the
-#' dataframe based on the combination of values in the specified columns.
+#' Takes a data.frame and a vector of column names and classifies each row of the
+#' data.frame based on the combination of values in the specified columns.
 #'
 #' What a visit should be is not always clearly defined and extractable in a
 #' dataset. A reasonable assumption is that a visit could be identified from the
@@ -206,7 +227,7 @@ getGridIDs <- function(x, grid){
 #' by the Darwin Core variables \code{c("locality", "day", "month", "year",
 #' "recordedBy")}.
 #'
-#' @param x An object of class \code{data.frame} or \code{SpatialPointsDataFrame}
+#' @param x An object of class \code{data.frame}, \code{sf} or \code{SpatialPointsDataFrame}
 #' including at least the columns specified that are used to identify a visit.
 #' @param idCols A vector with the names of the columns other (than time columns)
 #' that are used to identify a visit. This variable cannot be empty. At least the
@@ -216,10 +237,11 @@ getGridIDs <- function(x, grid){
 #' identify a visit.  If timeCols=NULL then time is ignored to create a visit ID.
 #' Default is the Darwin Core variables \code{c("day", "month", "year")}.
 #' @param grid Either \code{NULL} to be ignored or an object of class
-#' \code{SpatialPolygons} or \code{SpatialPolygonsDataFrame} defining the maximum
-#'  extent of visits effort. Then x must be an object of class SpatialPointsDataFrame
+#' \code{sf}, \code{SpatialPolygons} or \code{SpatialPolygonsDataFrame} defining
+#' the maximum extent of visits effort. Then x must be an object of class sf
+#' @param gridIdCol column in grid with ids.
 #'
-#' @return A vector of the same length as the number of rows as the dataframe
+#' @return A vector of the same length as the number of rows as the data.frame
 #'   with a unique number for each combination of the values in the specified
 #'   columns.
 #' @export
@@ -227,33 +249,39 @@ getGridIDs <- function(x, grid){
 #' OB <- organizeBirds(bombusObs)
 #' tmp.vis <- createVisits(bombusObs,
 #'                         idCols=c("locality", "recordedBy"),
-#'                         timeCols=c("day", "month", "year"))
+#'                         timeCols=c("day", "month", "year"),
+#'                         gridIdCol = "id")
 #' visits(OB, name = "visNoRecorder", useAsDefault = TRUE) <- tmp.vis
 createVisits<-function(x,
                        idCols = c("locality", "recordedBy"),
                        timeCols = c("day", "month", "year"),
-                       grid = NULL){
+                       grid = NULL,
+                       gridIdCol){
 
-  if(any(class(x) %in% c("data.frame", "SpatialPointsDataFrame"))){
-    if(any(class(x)=="data.frame")){
-      df <- as.data.frame(x) ## in case it is a data.table or some other weird class
-      spdf <- NULL
-    }else if (class(x)=="SpatialPointsDataFrame"){
+  if(any(class(x) %in% c("data.frame", "SpatialPointsDataFrame", "sf"))){
+    if (any(class(x)=="sf")){
+      df <- st_drop_geometry(x)
+      sfdf <- x
+    } else if (any(class(x)=="SpatialPointsDataFrame")){
       df <- x@data
-      spdf <- x
+      sfdf <- st_as_sf(x)
+    } else if(class(x)=="data.frame"){
+      df <- as.data.frame(x) ## in case it is a data.table or some other weird class
+      sfdf <- NULL
     }
 
     if (all(idCols == "")) idCols <- NULL
     if (all(timeCols=="")) timeCols <- NULL
 
     if(!is.null(grid)) {
-      if(class(grid) %in% c("SpatialPolygons", "SpatialPolygonsDataFrame")  & !is.null(spdf)){
-        df[,"gridID"] <- getGridIDs(spdf, grid)
+      if(any(class(grid) %in% c("SpatialPolygons", "SpatialPolygonsDataFrame", "sf"))
+         & !is.null(sfdf)){
+        df[,"gridID"] <- getGridIDs(sfdf, grid, gridIdCol)
       } else if(class(grid %in% c("character", "numeric"))){
         if(length(grid) == nrow(df)) {
           df[,"gridID"] <- grid
         } else stop("If grid is a vector it should be as long as the number of observations.")
-      } else stop("The argument 'grid' should be a SpatialPolygon or a vector with IDs.")
+      } else stop("The argument 'grid' should be a geometry or a vector with IDs.")
 
       gridID <- "gridID"
 
@@ -294,13 +322,17 @@ createVisits<-function(x,
 #'   the default column for the visits in further analysis. If name is
 #'   \code{NULL} and \code{useAsDefault = TRUE}, \code{value} will be written to
 #'   column (\code{visitUID}) and that column will be set to default.
+#' @param value the value to assign
 #'
 #' @export
 #' @examples
 #' ob <- organizeBirds(bombusObs)
 #' attr(ob, "visitCol")
 #' vis <- visits(ob)
-#' tmp.vis <- createVisits(bombusObs, idCols=c("locality"), timeCols = c("day", "month", "year"))
+#' tmp.vis <- createVisits(bombusObs,
+#'                         idCols=c("locality"),
+#'                         timeCols = c("day", "month", "year"),
+#'                         gridIdCol = "id")
 #' visits(ob, name = "visNoRecorder", useAsDefault = TRUE) <- tmp.vis
 #' vis2 <- visits(ob)
 #' attr(ob, "visitCol")
@@ -314,13 +346,15 @@ visits<-function(x, name=NULL){
     name<-attr(x, "visitCol")
   }
 
-  return(x[[1]]@data[,name])
+  return(st_drop_geometry(x[[1]][,name]))
 }
 
 #' @rdname visits
-#' @param value the value to assign
 #' @export
-'visits<-'<-function(x, name=NULL, useAsDefault = TRUE, value){
+'visits<-'<-function(x,
+                     name=NULL,
+                     useAsDefault = TRUE,
+                     value){
 
   if(is.null(name)){
     name <- "visitUID"
@@ -328,7 +362,7 @@ visits<-function(x, name=NULL){
 
   if(class(x)=="OrganizedBirds"){
 
-    x[[1]]@data[,name] <- value
+    x$spdf[,name] <- value
 
     if(useAsDefault){
       attr(x, "visitCol") <- name
@@ -363,7 +397,7 @@ visits<-function(x, name=NULL){
 #' Extract the observation data from a OrganizedBirds-object
 #'
 #' @param x An OrganizedBirds-object
-#' @return A dataframe
+#' @return A data.frame
 #' @export
 #'
 #' @examples
@@ -376,24 +410,28 @@ obsData<-function(x){
 #' @rdname obsData
 #' @export
 obsData.OrganizedBirds<-function(x){
-
-  return(x$spdf@data)
-
+  if(any(class(x$spdf) == "SpatialPointsDataFrame")) return(x$spdf@data)
+  if(any(class(x$spdf) == "sf")) return(st_drop_geometry(x$spdf))
 }
 
-#'Organize a dataframe to a usable format
+
+#### Main Function #####
+
+#'Organize a data.frame to a usable format
 #'
-#'Takes a dataframe with reported species observations and reformats it, using
+#'Takes a data.frame with reported species observations and reformats it, using
 #' visit identifiers, to an OrganizedBirds-class that can be used in further
 #' analyses with the BIRDS-package.
 #'
-#'An OrganizedBirds-class is essentially a list containing one element, a
-#'SpatialPointsDataFrame. This SpatialPointsDataFrame has its data formatted in
-#'a way that the other functions in the BIRDS-package can use further on. It
-#'also has the attribute \code{"visitCol"}, which indicates which column in the
-#'dataframe holds the visit identifier. The visit identifier is created by
-#'the function \code{\link{createVisits}}, which creates a unique id for each
-#'combination of the values in the defined columns.
+#'An OrganizedBirds-class is essentially a list containing a spatial element.
+#'After version 0.2, the resulting element is of class \code{sf}. However, we
+#'now add a parameter for backwards compatibility. It also accepts the inputs
+#'in both formats. This sf has its data formatted in a way that the other
+#'functions in the BIRDS-package can use further on. It also has the attribute
+#'\code{"visitCol"}, which indicates which column in the data.frame holds the
+#'visit identifier. The visit identifier is created by the function
+#'\code{\link{createVisits}}, which creates a unique id for each combination of
+#'the values in the defined columns.
 #'
 #'The variable \code{timeCol} can be formatted differently. If the variable is a
 #'named vector with the names "Year", "Month" and "Day" (letter capitalization
@@ -403,7 +441,7 @@ obsData.OrganizedBirds<-function(x){
 #'is of only length one it will interpret the column as a date column formatted
 #'as "yyyy-mm-dd".
 #'
-#' @param x A dataframe or a SpatialPointsDataFrame containing at least a
+#' @param x A data.frame, sf or a SpatialPointsDataFrame containing at least a
 #'  column for species name, one or several columns for date of observation, one or
 #'  several columns for identifying a visit and, if it is not spatial, coordinate
 #'  columns.
@@ -421,33 +459,33 @@ obsData.OrganizedBirds<-function(x){
 #' Alternatives are \code{c("day", "month", "year", NULL)}. Time is anyhow
 #' organised into three columns year, month, day.
 #' @param grid Either \code{NULL} to be ignored or an object of class
-#' \code{SpatialPolygons} or \code{SpatialPolygonsDataFrame} as indetifier of
+#' \code{SpatialPolygons} or \code{SpatialPolygonsDataFrame} as identifier of
 #' the visits spatial extent.
 #' @param presenceCol A character string with the column name for the column for the
-#' precense status. Default is \code{NULL}.
+#' presence status. Default is \code{NULL}.
 #' @param xyCols A character vector of the names for the columns that are holding
 #'  the coordinates for the observations. The order should be longitude(x),
 #'  latitude(y). Default is the Darwin Core standard column names
 #'  \code{c("decimalLongitude", "decimalLatitude")}. Only applicable to non-
-#'  spatial dataframes.
-#' @param dataCRS A character string for the dataframe CRS (Coordinate Reference
-#'  System). Default is \code{"+init=epsg:4326"}, which is WGS 84. This is only
-#'  applicable to non-spatial dataframes, since a spatial dataframes already
+#'  spatial data.frames.
+#' @param dataCRS A character string or numeric for the data.frame CRS (Coordinate Reference
+#'  System). Default is \code{4326}, which is WGS 84. This is only
+#'  applicable to non-spatial data.frames, since a spatial data.frames already
 #'  should have this information.
 #' @param taxonRankCol the name of the column containing the taxonomic rank for
 #' the observation.
 #' That is the minimum taxonomic identification level.
 #' @param taxonRank a string or vector of strings containing the taxonomic ranks to keep.
 #' Only evaluated if taxonRankCol is not \code{NULL}
-#' @param simplifySppName whether to remove everything else that is not the species
+#' @param simplifySppName Logical. whether to remove everything else that is not the species
 #' name (authors, years). Default set to FALSE, else leaves a canonical name given
 #' by taxize::gbif_parse(), that is a scientific name with up to 3 elements.
+#' @param spOut Logical. Whether the result should be a SpatialPolygon (sp) or an sf.
 #'
-#' @importFrom sp coordinates proj4string spTransform CRS plot
+#' @import sf
 #' @importFrom stats IQR median na.omit  quantile var
 #' @importFrom grDevices boxplot.stats
 #' @importFrom graphics barplot layout legend mtext par plot
-#' @importFrom methods as slot slot<-
 #' @return a `SpatialPointsDataFrame` wrapped into an object of class OrganizedBirds,
 #' with additional attributes.
 #' @export
@@ -456,7 +494,7 @@ obsData.OrganizedBirds<-function(x){
 #' @seealso \code{\link{createVisits}} to create unique visits IDs,
 #'  \code{\link{visits}} to get or set the visit IDs to this class,
 #'  \code{\link{simplifySpp}} to simplify species names,
-#'  \code{\link{obsData}} to retrieve the dataframe from this class.
+#'  \code{\link{obsData}} to retrieve the data.frame from this class.
 #' @aliases organiseBirds
 organizeBirds <- function(x,
                         sppCol = "scientificName",
@@ -466,11 +504,13 @@ organizeBirds <- function(x,
                         grid = NULL,
                         presenceCol = NULL,
                         xyCols = c("decimalLongitude", "decimalLatitude"),
-                        dataCRS = "+init=epsg:4326",
+                        dataCRS = 4326,
                         taxonRankCol=NULL,
                         taxonRank=c("SPECIES","SUBSPECIES","VARIETY"),
-                        simplifySppName=FALSE){
+                        simplifySppName=FALSE,
+                        spOut=FALSE){
 
+  crs <- st_crs(as.numeric(dataCRS))
   stdTimeCols <- c("year", "month", "day")
 
   # Check the type of data
@@ -486,66 +526,65 @@ organizeBirds <- function(x,
         xyColsl.df <- unlist(findCols(xyCols, x, exact=TRUE))
         if(length(xyColsl.df) == 0) stop("The column names defined for the coordinates could not be found in the data set")
       }
-      sp::coordinates(x) <- xyColsl.df
-      sp::proj4string(x) <- CRS(dataCRS)
+      x <- st_as_sf(x, coords = xyColsl.df)
+      st_crs(x) <- st_crs(as.numeric(dataCRS))
+      xdf <- st_drop_geometry(x)
 
     ### TODO Add message if CRS is not compatible with coordinates?? Do it with try.catch
-    # testCoord<-tryCatch({
-    #   sp::coordinates(xtest) <- xyColsl.df
-    #   sp::proj4string(xtest) <- CRS(epsgInfo$proj4)
-    # }, error = function(e){
-    #   # print(str(e$message))
-    #   return(e$message)
-    # }
 
     } else { stop("The column names defined for the coordinates could not be found in the data set")}
   } else if(any(class(x) == "SpatialPointsDataFrame")){
-    ## Just continue... :)
+    x <- st_as_sf(x)
+    xdf <- st_drop_geometry(x)
+  } else if(any(class(x) == "sf")){
+    xdf <- st_drop_geometry(x)## Just continue... :)
   } else {
-    stop("The argument 'x' should be of class data.frame or SpatialPointsDataFrame.")
+    stop("The argument 'x' should be of class data.frame, sf or SpatialPointsDataFrame.")
   }
 
-  if(slot(slot(x,"proj4string"), "projargs") != slot(CRS("+init=epsg:4326"),"projargs")){
-    x <- spTransform(x, CRSobj = CRS("+init=epsg:4326"))
+  if(st_crs(x) != crs){
+    x <- st_transform(x, crs = crs)
   }
 
   ### Check the column names
-  if (any(duplicated(tolower(names(x@data))))){
+  if (any(duplicated(tolower(names(x))))){
     stop("There are duplicated column names in the dataset (Note: case insensitive check).")
   }
 
   # Check if user wants to leave a certain level
   if (!is.null(taxonRankCol)){
-    TRCol.df <- findCols(taxonRankCol, x@data, exact = TRUE)
+    TRCol.df <- findCols(taxonRankCol, x, exact = TRUE)
     if (length(TRCol.df) > 0){
       exact.taxonRank <- paste0("\\b", taxonRank, "\\b") ## exact match
-      wIn <- unique(unlist(lapply(exact.taxonRank, grep,
-                                  x@data[, TRCol.df],
-                                  ignore.case = TRUE,
-                                  value = FALSE)))
-
-      nOut <- nrow(x@data) - length(wIn)
+      wIn <- unique(
+                unlist(
+                  lapply(exact.taxonRank,
+                         grep,
+                         st_drop_geometry(x)[, TRCol.df],
+                         ignore.case = TRUE,
+                         value = FALSE
+                        )
+                )
+              )
 
       if (length(wIn) > 0){
-        x<-x[wIn,]
+        nOut <- nrow(x) - length(wIn)
+        x <- x[wIn,]
         if(nOut > 0) message(paste0(nOut, " observations did not match with the specified taxon rank and were removed."))
-
       } else { stop(paste0("No observation match with the specified taxon rank(s).")) }
-
-
     } else { stop(paste0("Taxon Rank: there is no column called ", taxonRankCol))}
   }
 
-  # Simplify species names to reduce epitets and author names
-  sppCol.df <- findCols(sppCol, x@data, exact = TRUE)
+  # Simplify species names to reduce epithets and author names
+  sppCol.df <- findCols(sppCol, x, exact = TRUE)
   if (length(sppCol.df) > 0){
     if (!is.null(simplifySppName) && simplifySppName == TRUE){
-      x@data[, sppCol.df] <- simplifySpp(x@data, sppCol.df)
+      x[, sppCol.df] <- simplifySpp(st_drop_geometry(x), sppCol.df)
     }
   } else { stop(paste0("Species name: there is no column called ", sppCol))}
 
   ## column name control defined in the function organizeDate()
-  x@data[, stdTimeCols] <- organizeDate(x@data, timeCols)
+  x[, stdTimeCols] <- organizeDate(st_drop_geometry(x), timeCols)
 
 
   ## colum name control defined in the function visitUID()
@@ -559,18 +598,19 @@ organizeBirds <- function(x,
                           "year" = "year") ## Else NULL
   }
 
-  x@data[,"visitUID"] <- createVisits(x,
-                                      idCols = idCols,
-                                      timeCols = timeColsVis,
-                                      grid = grid)
+  x[,"visitUID"] <- createVisits(x,
+                                 idCols = idCols,
+                                 timeCols = timeColsVis,
+                                 grid = grid,
+                                 gridIdCol = NULL)
 
   #### Preparing the output as we want it
-  res.df <- x@data[,c(sppCol.df, stdTimeCols, "visitUID")]
+  res.df <- x[,c(sppCol.df, stdTimeCols, "visitUID", "geometry")]
 
   if (!is.null(presenceCol)){
-    presenceCol.df <- findCols(presenceCol, x@data)
+    presenceCol.df <- findCols(presenceCol, x)
     if (length(presenceCol.df) > 0){
-      presence <- x@data[, presenceCol.df]
+      presence <- x[, presenceCol.df]
       presence <- ifelse(presence>=1, 1, 0)
       res.df[,"presence"] <- presence
     } else {stop(paste0("Presence: there is no column called ", presenceCol))}
@@ -578,10 +618,11 @@ organizeBirds <- function(x,
 
   colnames(res.df)[1] <- "scientificName"
 
-  #### Add the visists SLL to each visits
-  x@data <- res.df
+  #### Add the visits SLL to each visits
+  x <- res.df
+  if(spOut) x <- as_Spatial(x)
 
-  res<-list(x)
+  res <- list(x)
 
   names(res)<-"spdf"
 
